==> ugene_1.5.2+repack.orig.tar.gz: ugene-1.5.2/src/plugins_3rdparty/hmm3/src/phmmer/uHMM3PhmmerDialogImpl.cpp <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/


#include <cassert>

#include <QtGui/QFileDialog>
#include <QtGui/QMessageBox>

#include <core_api/AppContext.h>
#include <gobjects/GObjectTypes.h>
#include <util_gui/DialogUtils.h>

#include <phmmer/uhmm3PhmmerTask.h>
#include "uHMM3PhmmerDialogImpl.h"

namespace GB2 {

const QString UHMM3PhmmerDialogImpl::QUERY_FILES_DIR            = "uhmm3_phmmer_query_files_dir";
const QString UHMM3PhmmerDialogImpl::DOM_E_PLUS_PREFIX          = "1E+";
const QString UHMM3PhmmerDialogImpl::DOM_E_MINUS_PREFIX         = "1E";
const QString UHMM3PhmmerDialogImpl::ANNOTATIONS_DEFAULT_NAME   = "signal";

UHMM3PhmmerDialogImpl::UHMM3PhmmerDialogImpl( const DNASequenceObject * seqObj, QWidget * p ) : QDialog( p ) {
    assert( NULL != seqObj );
    setupUi( this );
    
    model.dbSequence = seqObj->getDNASequence();
    setModelValues(); // default model here
    
    // Annotations widget
    CreateAnnotationModel annModel;
    annModel.hideLocation = true;
    annModel.sequenceObjectRef = seqObj;
    annModel.data->name = ANNOTATIONS_DEFAULT_NAME;
    annModel.sequenceLen = seqObj->getSequenceLen();
    annotationsWidgetController = new CreateAnnotationWidgetController( annModel, this );
    QWidget * firstTab = mainTabWidget->widget( 0 );
    assert( NULL != firstTab );
    QVBoxLayout * curLayout = qobject_cast< QVBoxLayout* >( firstTab->layout() );
    assert( NULL != curLayout );
    curLayout->insertWidget( ANNOTATIONS_WIDGET_LOCATION, annotationsWidgetController->getWidget() );
    firstTab->setMinimumHeight( firstTab->size().height() );
    
    connect( queryToolButton, SIGNAL( clicked() ), SLOT( sl_queryToolButtonClicked() ) );
    connect( okPushButton, SIGNAL( clicked() ), SLOT( sl_okButtonClicked() ) );
    connect( cancelPushButton, SIGNAL( clicked() ), SLOT( sl_cancelButtonClicked() ) );
    connect( useEvalTresholdsButton, SIGNAL( toggled( bool ) ), SLOT( sl_useEvalTresholdsButtonChanged( bool ) ) );
    connect( useScoreTresholdsButton, SIGNAL( toggled( bool ) ), SLOT( sl_useScoreTresholdsButtonChanged( bool ) ) );
    connect( domZCheckBox, SIGNAL( stateChanged( int ) ), SLOT( sl_domZCheckBoxChanged( int ) ) );
    connect( maxCheckBox, SIGNAL( stateChanged( int ) ), SLOT( sl_maxCheckBoxChanged( int ) ) );
    connect( domESpinBox, SIGNAL( valueChanged( int ) ), SLOT( sl_domESpinBoxChanged( int ) ) );
}

void UHMM3PhmmerDialogImpl::setModelValues() {
    const UHMM3PhmmerSettings & settings = model.phmmerSettings;
    domESpinBox->setValue( 1 ); assert( 10.0 == settings.domE );
    scoreTresholdDoubleSpin->setValue( settings.domT );
    f1DoubleSpinBox->setValue( settings.f1 );
    f2DoubleSpinBox->setValue( settings.f2 );
    f3DoubleSpinBox->setValue( settings.f3 );
    seedSpinBox->setValue( settings.seed );
    emlSpinBox->setValue( settings.eml );
    emnSpinBox->setValue( settings.emn );
    evlSpinBox->setValue( settings.evl );
    evnSpinBox->setValue( settings.evn );
    eflSpinBox->setValue( settings.efl );
    efnSpinBox->setValue( settings.efn );
    eftDoubleSpinBox->setValue( settings.eft );
    popenDoubleSpinBox->setValue( settings.popen );
    pextendDoubleSpinBox->setValue( settings.pextend );
}

void UHMM3PhmmerDialogImpl::sl_queryToolButtonClicked() {
    LastOpenDirHelper helper( QUERY_FILES_DIR );
    helper.url = QFileDialog::getOpenFileName( this, tr( "Select query sequence file" ),
        helper, DialogUtils::prepareDocumentsFileFilterByObjType( GObjectTypes::DNA_SEQUENCE, true ) );
    if( !helper.url.isEmpty() ) {
        queryLineEdit->setText( helper.url );
    }
}

void UHMM3PhmmerDialogImpl::sl_cancelButtonClicked() {
    reject();
}

void UHMM3PhmmerDialogImpl::getModelValues() {
    UHMM3PhmmerSettings & settings = model.phmmerSettings;
    
    model.queryfile = queryLineEdit->text();
    if( useEvalTresholdsButton->isChecked() ) {
        settings.domE = pow( 10.0, domESpinBox->value() );
        settings.domT = OPTION_NOT_SET;
    } else if( useScoreTresholdsButton->isChecked() ) {
        settings.domT = scoreTresholdDoubleSpin->value();
    } else {
        assert( false );
    }
    
    settings.popen = popenDoubleSpinBox->value();
    settings.pextend = pextendDoubleSpinBox->value();
    
    settings.noBiasFilter = nobiasCheckBox->isChecked();
    settings.noNull2 = nonull2CheckBox->isChecked();
    settings.doMax = maxCheckBox->isChecked();
    settings.f1 = f1DoubleSpinBox->value();
    settings.f2 = f2DoubleSpinBox->value();
    settings.f3 = f3DoubleSpinBox->value();
    
    settings.eml         = emlSpinBox->value();
    settings.emn         = emnSpinBox->value();
    settings.evl         = evlSpinBox->value();
    settings.evn         = evnSpinBox->value();
    settings.efl         = eflSpinBox->value();
    settings.efn         = efnSpinBox->value();
    settings.eft         = eftDoubleSpinBox->value();
    settings.seed        = seedSpinBox->value();
}

QString UHMM3PhmmerDialogImpl::checkModel() {
    assert( model.phmmerSettings.isValid() );
    QString ret;
    if( model.queryfile.isEmpty() ) {
        ret = tr( "Query sequence file path is empty" );
        return ret;
    }
    ret = annotationsWidgetController->validate();
    if( !ret.isEmpty() ) {
        QMessageBox::critical( this, tr( "Error: bad arguments!" ), ret );
        return ret;
    }
    
    return ret;
}

void UHMM3PhmmerDialogImpl::sl_okButtonClicked() {
    getModelValues();
    QString err = checkModel();
    if( !err.isEmpty() ) {
        QMessageBox::critical( this, tr( "Error: bad arguments!" ), err );
        return;
    }
    
    annotationsWidgetController->prepareAnnotationObject();
    const CreateAnnotationModel & annModel = annotationsWidgetController->getModel();
    UHMM3PhmmerToAnnotationsTask * phmmerTask = new UHMM3PhmmerToAnnotationsTask( model.queryfile, model.dbSequence,
        annModel.getAnnotationObject(), annModel.groupName, annModel.data->name, model.phmmerSettings );
    AppContext::getTaskScheduler()->registerTopLevelTask( phmmerTask );
    
    QDialog::accept();
}

void UHMM3PhmmerDialogImpl::sl_useEvalTresholdsButtonChanged( bool checked ) {
    domESpinBox->setEnabled( checked );
}

void UHMM3PhmmerDialogImpl::sl_useScoreTresholdsButtonChanged( bool checked ) {
    scoreTresholdDoubleSpin->setEnabled( checked );
}

void UHMM3PhmmerDialogImpl::sl_domZCheckBoxChanged( int state ) {
    assert( Qt::PartiallyChecked != state );
    bool checked = Qt::Checked == state;
    domZDoubleSpinBox->setEnabled( checked );
}

void UHMM3PhmmerDialogImpl::sl_maxCheckBoxChanged( int state ) {
    assert( Qt::PartiallyChecked != state );
    bool unchecked = Qt::Unchecked == state;
    f1Label->setEnabled( unchecked );
    f2Label->setEnabled( unchecked );
    f3Label->setEnabled( unchecked );
    f1DoubleSpinBox->setEnabled( unchecked );
    f2DoubleSpinBox->setEnabled( unchecked );
    f3DoubleSpinBox->setEnabled( unchecked );
}

void UHMM3PhmmerDialogImpl::sl_domESpinBoxChanged( int newVal ) {
    const QString & prefix = 0 <= newVal ? DOM_E_PLUS_PREFIX : DOM_E_MINUS_PREFIX;
    domESpinBox->setPrefix( prefix );
}

} // GB2

==> ugene_1.7.1+repack.orig.tar.gz: ugene-1.7.1/src/plugins_3rdparty/hmm3/src/phmmer/uHMM3PhmmerDialogImpl.cpp <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/


#include <cassert>

#include <QtGui/QFileDialog>
#include <QtGui/QMessageBox>

#include <core_api/AppContext.h>
#include <gobjects/GObjectTypes.h>
#include <util_gui/DialogUtils.h>

#include <phmmer/uhmm3PhmmerTask.h>
#include "uHMM3PhmmerDialogImpl.h"

namespace GB2 {

const QString UHMM3PhmmerDialogImpl::QUERY_FILES_DIR            = "uhmm3_phmmer_query_files_dir";
const QString UHMM3PhmmerDialogImpl::DOM_E_PLUS_PREFIX          = "1E+";
const QString UHMM3PhmmerDialogImpl::DOM_E_MINUS_PREFIX         = "1E";
const QString UHMM3PhmmerDialogImpl::ANNOTATIONS_DEFAULT_NAME   = "signal";

UHMM3PhmmerDialogImpl::UHMM3PhmmerDialogImpl( const DNASequenceObject * seqObj, QWidget * p ) : QDialog( p ) {
    assert( NULL != seqObj );
    setupUi( this );
    
    model.dbSequence = seqObj->getDNASequence();
    setModelValues(); // default model here
    
    // Annotations widget
    CreateAnnotationModel annModel;
    annModel.hideLocation = true;
    annModel.sequenceObjectRef = seqObj;
    annModel.data->name = ANNOTATIONS_DEFAULT_NAME;
    annModel.sequenceLen = seqObj->getSequenceLen();
    annotationsWidgetController = new CreateAnnotationWidgetController( annModel, this );
    QWidget * firstTab = mainTabWidget->widget( 0 );
    assert( NULL != firstTab );
    QVBoxLayout * curLayout = qobject_cast< QVBoxLayout* >( firstTab->layout() );
    assert( NULL != curLayout );
    curLayout->insertWidget( ANNOTATIONS_WIDGET_LOCATION, annotationsWidgetController->getWidget() );
    firstTab->setMinimumHeight( firstTab->size().height() );
    
    connect( queryToolButton, SIGNAL( clicked() ), SLOT( sl_queryToolButtonClicked() ) );
    connect( okPushButton, SIGNAL( clicked() ), SLOT( sl_okButtonClicked() ) );
    connect( cancelPushButton, SIGNAL( clicked() ), SLOT( sl_cancelButtonClicked() ) );
    connect( useEvalTresholdsButton, SIGNAL( toggled( bool ) ), SLOT( sl_useEvalTresholdsButtonChanged( bool ) ) );
    connect( useScoreTresholdsButton, SIGNAL( toggled( bool ) ), SLOT( sl_useScoreTresholdsButtonChanged( bool ) ) );
    connect( domZCheckBox, SIGNAL( stateChanged( int ) ), SLOT( sl_domZCheckBoxChanged( int ) ) );
    connect( maxCheckBox, SIGNAL( stateChanged( int ) ), SLOT( sl_maxCheckBoxChanged( int ) ) );
    connect( domESpinBox, SIGNAL( valueChanged( int ) ), SLOT( sl_domESpinBoxChanged( int ) ) );
}

void UHMM3PhmmerDialogImpl::setModelValues() {
    const UHMM3PhmmerSettings & settings = model.phmmerSettings;
    domESpinBox->setValue( 1 ); assert( 10.0 == settings.domE );
    scoreTresholdDoubleSpin->setValue( settings.domT );
    f1DoubleSpinBox->setValue( settings.f1 );
    f2DoubleSpinBox->setValue( settings.f2 );
    f3DoubleSpinBox->setValue( settings.f3 );
    seedSpinBox->setValue( settings.seed );
    emlSpinBox->setValue( settings.eml );
    emnSpinBox->setValue( settings.emn );
    evlSpinBox->setValue( settings.evl );
    evnSpinBox->setValue( settings.evn );
    eflSpinBox->setValue( settings.efl );
    efnSpinBox->setValue( settings.efn );
    eftDoubleSpinBox->setValue( settings.eft );
    popenDoubleSpinBox->setValue( settings.popen );
    pextendDoubleSpinBox->setValue( settings.pextend );
}

void UHMM3PhmmerDialogImpl::sl_queryToolButtonClicked() {
    LastOpenDirHelper helper( QUERY_FILES_DIR );
    helper.url = QFileDialog::getOpenFileName( this, tr( "Select query sequence file" ),
        helper, DialogUtils::prepareDocumentsFileFilterByObjType( GObjectTypes::SEQUENCE, true ) );
    if( !helper.url.isEmpty() ) {
        queryLineEdit->setText( helper.url );
    }
}

void UHMM3PhmmerDialogImpl::sl_cancelButtonClicked() {
    reject();
}

void UHMM3PhmmerDialogImpl::getModelValues() {
    UHMM3PhmmerSettings & settings = model.phmmerSettings;
    
    model.queryfile = queryLineEdit->text();
    if( useEvalTresholdsButton->isChecked() ) {
        settings.domE = pow( 10.0, domESpinBox->value() );
        settings.domT = OPTION_NOT_SET;
    } else if( useScoreTresholdsButton->isChecked() ) {
        settings.domT = scoreTresholdDoubleSpin->value();
    } else {
        assert( false );
    }
    
    settings.popen = popenDoubleSpinBox->value();
    settings.pextend = pextendDoubleSpinBox->value();
    
    settings.noBiasFilter = nobiasCheckBox->isChecked();
    settings.noNull2 = nonull2CheckBox->isChecked();
    settings.doMax = maxCheckBox->isChecked();
    settings.f1 = f1DoubleSpinBox->value();
    settings.f2 = f2DoubleSpinBox->value();
    settings.f3 = f3DoubleSpinBox->value();
    
    settings.eml         = emlSpinBox->value();
    settings.emn         = emnSpinBox->value();
    settings.evl         = evlSpinBox->value();
    settings.evn         = evnSpinBox->value();
    settings.efl         = eflSpinBox->value();
    settings.efn         = efnSpinBox->value();
    settings.eft         = eftDoubleSpinBox->value();
    settings.seed        = seedSpinBox->value();
}

QString UHMM3PhmmerDialogImpl::checkModel() {
    assert( model.phmmerSettings.isValid() );
    QString ret;
    if( model.queryfile.isEmpty() ) {
        ret = tr( "Query sequence file path is empty" );
        return ret;
    }
    ret = annotationsWidgetController->validate();
    if( !ret.isEmpty() ) {
        QMessageBox::critical( this, tr( "Error: bad arguments!" ), ret );
        return ret;
    }
    
    return ret;
}

void UHMM3PhmmerDialogImpl::sl_okButtonClicked() {
    getModelValues();
    QString err = checkModel();
    if( !err.isEmpty() ) {
        QMessageBox::critical( this, tr( "Error: bad arguments!" ), err );
        return;
    }
    
    annotationsWidgetController->prepareAnnotationObject();
    const CreateAnnotationModel & annModel = annotationsWidgetController->getModel();
    UHMM3PhmmerToAnnotationsTask * phmmerTask = new UHMM3PhmmerToAnnotationsTask( model.queryfile, model.dbSequence,
        annModel.getAnnotationObject(), annModel.groupName, annModel.data->name, model.phmmerSettings );
    AppContext::getTaskScheduler()->registerTopLevelTask( phmmerTask );
    
    QDialog::accept();
}

void UHMM3PhmmerDialogImpl::sl_useEvalTresholdsButtonChanged( bool checked ) {
    domESpinBox->setEnabled( checked );
}

void UHMM3PhmmerDialogImpl::sl_useScoreTresholdsButtonChanged( bool checked ) {
    scoreTresholdDoubleSpin->setEnabled( checked );
}

void UHMM3PhmmerDialogImpl::sl_domZCheckBoxChanged( int state ) {
    assert( Qt::PartiallyChecked != state );
    bool checked = Qt::Checked == state;
    domZDoubleSpinBox->setEnabled( checked );
}

void UHMM3PhmmerDialogImpl::sl_maxCheckBoxChanged( int state ) {
    assert( Qt::PartiallyChecked != state );
    bool unchecked = Qt::Unchecked == state;
    f1Label->setEnabled( unchecked );
    f2Label->setEnabled( unchecked );
    f3Label->setEnabled( unchecked );
    f1DoubleSpinBox->setEnabled( unchecked );
    f2DoubleSpinBox->setEnabled( unchecked );
    f3DoubleSpinBox->setEnabled( unchecked );
}

void UHMM3PhmmerDialogImpl::sl_domESpinBoxChanged( int newVal ) {
    const QString & prefix = 0 <= newVal ? DOM_E_PLUS_PREFIX : DOM_E_MINUS_PREFIX;
    domESpinBox->setPrefix( prefix );
}

} // GB2
